Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
src / crump / __init__.py |  | 5 | 0 | 0 |  | 100%
src / crump / cdf_extractor.py |  | 260 | 35 | 0 |  | 87%
src / crump / cdf_reader.py |  | 134 | 32 | 0 |  | 76%
src / crump / cli.py |  | 15 | 0 | 0 |  | 100%
src / crump / cli_extract.py |  | 168 | 24 | 0 |  | 86%
src / crump / cli_inspect.py |  | 210 | 38 | 0 |  | 82%
src / crump / cli_prepare.py |  | 214 | 17 | 0 |  | 92%
src / crump / cli_sync.py |  | 140 | 35 | 0 |  | 75%
src / crump / config.py |  | 401 | 38 | 0 |  | 91%
src / crump / console_utils.py |  | 8 | 1 | 0 |  | 88%
src / crump / csv_file.py |  | 51 | 1 | 0 |  | 98%
src / crump / database.py |  | 642 | 55 | 0 |  | 91%
src / crump / file_types.py |  | 37 | 1 | 0 |  | 97%
src / crump / history.py |  | 37 | 0 | 2 |  | 100%
src / crump / parquet_file.py |  | 79 | 5 | 0 |  | 94%
src / crump / tabular_file.py |  | 76 | 20 | 0 |  | 74%
src / crump / type_detection.py |  | 100 | 2 | 0 |  | 98%
Total |  | 2577 | 304 | 2 |  | 88%

No items found using the specified filter.